aboutsummaryrefslogtreecommitdiff
path: root/src/lib/err/torerr_sys.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/err/torerr_sys.c')
-rw-r--r--src/lib/err/torerr_sys.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/lib/err/torerr_sys.c b/src/lib/err/torerr_sys.c
index c42e958093..46fc853550 100644
--- a/src/lib/err/torerr_sys.c
+++ b/src/lib/err/torerr_sys.c
@@ -1,4 +1,4 @@
-/* Copyright (c) 2018-2019, The Tor Project, Inc. */
+/* Copyright (c) 2018-2020, The Tor Project, Inc. */
/* See LICENSE for licensing information */
/**
@@ -27,8 +27,9 @@ subsys_torerr_initialize(void)
static void
subsys_torerr_shutdown(void)
{
/* Stop handling signals with backtraces. */
clean_up_backtrace_handler();
+ tor_log_flush_sigsafe_err_fds();
}
const subsys_fns_t sys_torerr = {
@@ -27,8 +27,9 @@ subsys_torerr_initialize(void)
subsys_torerr_shutdown(void)
{
- /* Stop handling signals with backtraces. */
+ /* Stop handling signals with backtraces, then flush the logs. */
clean_up_backtrace_handler();